@@ -41,13 +41,18 @@
 #' cycleGraph fixedSequence generalSuccessive simpleSuccessiveI
 #' simpleSuccessiveII truncatedHolm fallback HuqueAloshEtBhore2011
 #' BauerEtAl2001 BretzEtAl2009a BretzEtAl2009b BretzEtAl2009c Ferber2011
-#' Entangled1Maurer2012 Entangled2Maurer2012 FerberTimeDose2011
+#' Entangled1Maurer2012 Entangled2Maurer2012 FerberTimeDose2011 WangTing2014
 #' @param n Number of hypotheses.
 #' @param nodes Character vector of node names.
 #' @param weights Numeric vector of node weights.
 #' @param times Number of time points.
 #' @param doses Number of dose levels.
 #' @param w Further variable weight(s) in graph.
+#' @param gamma An optional number in [0,1] specifying the value for variable gamma.
+#' @param delta An optional number in [0,1] specifying the value for variable delta.
+#' @param nu An optional number in [0,1] specifying the value for variable nu.
+#' @param tau An optional number in [0,1] specifying the value for variable tau.
+#' @param omega An optional number in [0,1] specifying the value for variable omega.
 #' @return A graph of class \code{\link{graphMCP}} that represents a
 #' sequentially rejective multiple test procedure.
 #' @author Kornelius Rohmeyer \email{rohmeyer@@small-projects.de}
@@ -82,13 +87,17 @@
 #' der chemisch-pharmazeutischen Industrie, Vollmar J (ed.). Fischer Verlag:
 #' Stuttgart, 1995; 3-18.
 #' 
-#' Maurer, W., & Bretz, F. (2012). Memory and other properties of multiple test
-#' procedures generated by entangled graphs. Statistics in medicine.
+#' Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test 
+#' procedures generated by entangled graphs. Statistics in medicine, 32 (10), 1739-1753.
 #' 
 #' Wiens, B.L., Dmitrienko, A. (2005): The fallback procedure for evaluating a
 #' single family of hypotheses. Journal of Biopharmaceutical Statistics
 #' 15:929-942.
 #' 
+#' Wang, B., Ting, N. (2014). An Application of Graphical Approach to 
+#' Construct Multiple Testing Procedures in a Hypothetical Phase III Design. 
+#' Frontiers in public health, 1 (75).
+#' 
 #' Ferber, G. Staner, L. and Boeijinga, P. (2011): Structured multiplicity and
 #' confirmatory statistical analyses in pharmacodynamic studies using the
 #' quantitative electroencephalogram, Journal of neuroscience methods, Volume
@@ -96,17 +105,12 @@
 #' @keywords misc graphs
 #' @examples
 #' 
-#' 
 #' g <- BonferroniHolm(5)
 #' 
-#' \dontrun{
-#' # If Rgraphviz is installed, we can take a look at the graph:
-#' library(Rgraphviz)
-#' renderGraph(layoutGraph(g))
-#' }
-#' 
 #' gMCP(g, pvalues=c(0.1, 0.2, 0.4, 0.4, 0.7))
 #' 
+#' HungEtWang2010()
+#' HungEtWang2010(nu=1)
 #' 
 NULL
 
@@ -186,7 +190,7 @@ BretzEtAl2011 <- function() {
 			"",
 			"Since in this example it is preferred to reject two adjacent hypotheses (like H11 and H21 instead of H11 and H31) there are only edges between adjacent nodes.",
 			"",
-			"Literature: Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: n/a.", sep="\n")
+			"Literature: Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: 1489-1501.", sep="\n")
 	return(graph)	
 }
 
@@ -482,7 +486,7 @@ simpleSuccessiveII <- function() {
 }
 
 #' @rdname exampleGraphs
-truncatedHolm <- function() {
+truncatedHolm <- function(gamma) {
 	# Nodes:
 	weights <- c(1/2, 1/2, 0, 0)
 	hnodes <- paste("H", 1:4, sep="")
@@ -505,6 +509,9 @@ truncatedHolm <- function() {
 			"Literature: Dmitrienko A, Tamhane A, Wiens B. General multi-stage gatekeeping procedures. Biometrical Journal 2008; 50:667-677.",
 			"",
 			"F. Bretz, M. Posch, E. Glimm, F. Klinglmueller, W. Maurer, K. Rohmeyer (2011), Graphical approaches for multiple comparison procedures using weighted Bonferroni, Simes or parametric tests. To be published. Figure 5.", sep="\n")
+	if (!missing(gamma)) {
+	  graph <- replaceVariables(graph, variables=list("gamma"=gamma))
+	}
 	return(graph)
 }
 
@@ -517,7 +524,7 @@ truncatedHolm <- function() {
 #   another secondary hypothesis that has not the same parents.
 
 #' @rdname exampleGraphs
-generalSuccessive <- function(weights=c(1/2,1/2)) {
+generalSuccessive <- function(weights=c(1/2,1/2), gamma, delta) {
 	if (length(weights)!=2) stop("Please specify the weights for H1 and H2 and only these.")
 	# Nodes:
 	weights <- c(weights, 0, 0)
@@ -538,7 +545,13 @@ generalSuccessive <- function(weights=c(1/2,1/2)) {
 	graph@nodeAttr$Y <- nodeY	
 	attr(graph, "description") <- paste("General successive graph from Bretz et al. (2011), Figure 6", 
 			"",
-			"Literature: Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: n/a.", sep="\n")
+			"Literature: Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: 1489-1501.", sep="\n")
+	variables <- list()
+	if (!missing(gamma)) variables[["gamma"]] <- gamma
+	if (!missing(delta)) variables[["delta"]] <- delta	
+	if (length(variables)>0) {
+	  graph <- replaceVariables(graph, variables=variables, partial=TRUE)
+	}
 	return(graph)		
 }
 
@@ -559,7 +572,7 @@ HuqueAloshEtBhore2011 <- function() {
 }
 
 #' @rdname exampleGraphs
-HungEtWang2010 <- function() {
+HungEtWang2010 <- function(nu, tau, omega) {
 	# Nodes:
 	weights <- c(1,0,0,0)	
 	hnodes <- c("H_{1,NI}","H_{1,S}","H_{2,NI}","H_{2,S}")
@@ -584,6 +597,13 @@ HungEtWang2010 <- function() {
 			"H_{2,S}  : Superiority of the secondary endpoint",
 			"",
 			"Literature: Hung H.M.J., Wang S.-J. (2010). Challenges to multiple testing in clinical trials. Biometrical Journal 52, 747-756.", sep="\n")
+  variables <- list()
+  if (!missing(nu)) variables[["nu"]] <- nu
+	if (!missing(omega)) variables[["omega"]] <- omega
+	if (!missing(tau)) variables[["tau"]] <- tau
+  if (length(variables)>0) {
+	  graph <- replaceVariables(graph, variables=variables, partial=TRUE)
+  }
 	return(graph)
 }
 
@@ -681,7 +701,7 @@ improvedFallbackI <- function(weights=rep(1/3, 3)) {
 			"",
 			"Literature: B.L. Wiens, A. Dmitrienko (2005): The fallback procedure for evaluating a single family of hypotheses. Journal of Biopharmaceutical Statistics 15:929-942.",
 			"",
-			"Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: n/a.", sep="\n")
+			"Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: 1489-1501.", sep="\n")
 	edgeAttr(graph, "H3", "H1", "labelX") <- 300
 	edgeAttr(graph, "H3", "H1", "labelY") <- 200
 	edgeAttr(graph, "H2", "H3", "labelX") <- 400
@@ -708,7 +728,7 @@ improvedFallbackII <- function(weights=rep(1/3, 3)) {
 			"",
 			"Literature: G. Hommel, F. Bretz (2008): Aesthetics and power considerations in multiple testing - a contradiction? Biometrical Journal 50:657-666.",
 			"",
-			"Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: n/a.", sep="\n")
+			"Bretz, F., Maurer, W. and Hommel, G. (2011), Test and power considerations for multiple endpoint analyses using sequentially rejective graphical procedures. Statistics in Medicine, 30: 1489-1501.", sep="\n")
 	edgeAttr(graph, "H3", "H1", "labelX") <- 300
 	edgeAttr(graph, "H3", "H1", "labelY") <- 200
 	edgeAttr(graph, "H1", "H2", "labelX") <- 200
@@ -751,7 +771,7 @@ FerberTimeDose2011 <- function(times, doses, w="\\nu") {
 }
 
 #' @rdname exampleGraphs
-Ferber2011 <- function() {
+Ferber2011 <- function(w) {
 	# Nodes:
 	hnodes <- c("\\delta", "\\theta", "\\beta", "\\alpha", "\\alpha_1", 
 			"\\alpha_2", "\\beta_1", "\\beta_2", "\\beta_3")
@@ -796,6 +816,10 @@ Ferber2011 <- function() {
 							"\\theta", "\\beta", "\\alpha", "\\alpha_1", "\\alpha_2", 
 							"\\beta_1", "\\beta_2", "\\beta_3")))
 	
+	if (!missing(w)) {
+	  graph <- replaceVariables(graph, variables=list("w"=w))
+	}
+  
 	return(graph)
 }
 
@@ -858,7 +882,7 @@ Entangled1Maurer2012 <- function() {
 
 	attr(graph, "description") <- paste("Graph from Maurer and Bretz 2012",
 			"",
-			"Literature: Maurer, W., & Bretz, F. (2012). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine.", sep="\n")
+			"Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), 1739-1753.", sep="\n")
 	
 	return(graph)
 }
@@ -898,7 +922,59 @@ Entangled2Maurer2012 <- function() {
 	
 	attr(graph, "description") <- paste("Graph from Maurer and Bretz 2012",
 			"",
-			"Literature: Maurer, W., & Bretz, F. (2012). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine.", sep="\n")
+			"Literature: Maurer, W., & Bretz, F. (2013). Memory and other properties of multiple test procedures generated by entangled graphs. Statistics in medicine, 32(10), 1739-1753.", sep="\n")
 	
 	return(graph)
 }
+
+#' @rdname exampleGraphs
+WangTing2014 <- function(nu, tau) {
+  m <- rbind(H1=c("0", "1-\\nu", "\\nu/2", "\\nu/2", "0", "0"),
+             H2=c("1-\\nu", "0", "0", "0", "\\nu/2", "\\nu/2"),
+             H3=c("0", "\\tau", "0", "1-\\tau", "0", "0"),
+             H4=c("0", "\\tau", "1-\\tau", "0", "0", "0"),
+             H5=c("\\tau", "0", "0", "0", "0", "1-\\tau"),
+             H6=c("\\tau", "0", "0", "0", "1-\\tau", "0"))
+  
+  weights <- c(1/2, 1/2, 0, 0, 0, 0)
+  
+  graph <- new("graphMCP", m=m, weights=weights)
+  
+  graph@nodeAttr$X <- c(350, 350, 100, 250, 450, 600)-50
+  graph@nodeAttr$Y <- c(100, 400, 250, 250, 250, 250)-50
+  
+  edgeAttr(graph, "H1", "H3", "labelX") <- 125
+  edgeAttr(graph, "H1", "H3", "labelY") <- 125
+  edgeAttr(graph, "H1", "H4", "labelX") <- 225
+  edgeAttr(graph, "H1", "H4", "labelY") <- 125
+  edgeAttr(graph, "H3", "H2", "labelX") <- 125
+  edgeAttr(graph, "H3", "H2", "labelY") <- 275
+  edgeAttr(graph, "H4", "H2", "labelX") <- 225
+  edgeAttr(graph, "H4", "H2", "labelY") <- 275
+  
+  edgeAttr(graph, "H6", "H1", "labelX") <- 550-125+50
+  edgeAttr(graph, "H6", "H1", "labelY") <- 125
+  edgeAttr(graph, "H5", "H1", "labelX") <- 550-225+50
+  edgeAttr(graph, "H5", "H1", "labelY") <- 125
+  edgeAttr(graph, "H2", "H6", "labelX") <- 550-125+50
+  edgeAttr(graph, "H2", "H6", "labelY") <- 275
+  edgeAttr(graph, "H2", "H5", "labelX") <- 550-225+50
+  edgeAttr(graph, "H2", "H5", "labelY") <- 275
+  
+  attr(graph, "description") <- paste("Graph from Wang and Ting 2014",
+                                      "With \u03BD=1, \u2CA7=0.5 graph from figure 3,",
+                                      "with \u03BD=1, \u2CA7=\u03B5 graph from figure 4 and",
+                                      "with \u03BD=\u03B5, \u2CA7=\u03B5 graph from figure 5.",
+                                      "",
+                                      "Literature: Wang, B., Ting, N. (2014). An Application of Graphical Approach to Construct Multiple Testing Procedures in a Hypothetical Phase III Design. Frontiers in public health, 1 (75).",
+                                      "URL: http://journal.frontiersin.org/Journal/10.3389/fpubh.2013.00075/full", sep="\n")
+  
+  variables <- list()
+  if (!missing(nu)) variables[["nu"]] <- nu
+  if (!missing(tau)) variables[["tau"]] <- tau
+  if (length(variables)>0) {
+    graph <- replaceVariables(graph, variables=variables, partial=TRUE)
+  }
+  
+  return(graph)
+}
\ No newline at end of file
