@@ -36,6 +36,7 @@ import org.af.gMCP.gui.dialogs.VariableNameDialog;
 import org.apache.commons.lang.ArrayUtils;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.xmlbeans.impl.xb.xmlconfig.ConfigDocument.Config;
 import org.jdesktop.swingworker.SwingWorker;
 import org.mutoss.gui.TransferableImage;
 
@@ -178,13 +179,11 @@ public class GraphView extends JPanel implements ActionListener {
 	
 	public void actionPerformed(ActionEvent e) {
 		if (!e.getSource().equals(buttonNewNode)) {
-			nl.newVertex = false;
+			nl.setNewVertex(false);
 			buttonNewNode.setSelected(false);
 		}
 		if (!e.getSource().equals(buttonNewEdge)) {
-			nl.newEdge = false;
-			nl.arrowHeadPoint = null;
-			nl.firstVertexSelected = false;
+			nl.setNewEdge(false);			
 		}
 		if (e.getSource().equals(buttonZoomIn)) {
 			nl.setZoom(nl.getZoom() * 1.25);
@@ -197,12 +196,12 @@ public class GraphView extends JPanel implements ActionListener {
 				JOptionPane.showMessageDialog(parent, "Highest zoom level. This is no Mandelbrot set.", "Highest zoom level", JOptionPane.INFORMATION_MESSAGE);
 			}
 		} else if (e.getSource().equals(buttonNewEdge)) {
-			ReproducableLog.logGUI("Button \"new edge\"");
-			nl.newEdge = true;
+			ReproducableLog.logGUI("Button \"new edge\"");			
+			nl.setNewEdge(true);
 			getNL().statusBar.setText("Select a node from which this edge should start.");
 		} else if (e.getSource().equals(buttonNewNode)) {
 			ReproducableLog.logGUI("Button \"new node\"");
-			nl.newVertex = buttonNewNode.isSelected();
+			nl.setNewVertex(buttonNewNode.isSelected());
 			nl.repaint();
 			getNL().statusBar.setText("Click on the graph panel to place the node.");
 		} else if (e.getSource().equals(buttonConfInt)) {
@@ -226,8 +225,9 @@ public class GraphView extends JPanel implements ActionListener {
 					protected Void doInBackground() throws Exception {
 						try {
 							if (!isResultUpToDate()) {
+								rCode = RControl.setSeed();
 								RControl.getR().evalVoid(result+" <- gMCP("+getNL().initialGraph+getGMCPOptions()+")");
-								rCode = RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
+								rCode += RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
 								setResultUpToDate(true);
 							}
 							double[] alpha = RControl.getR().eval(""+getPView().getTotalAlpha()+"*getWeights("+result+")").asRNumeric().getData();
@@ -235,8 +235,9 @@ public class GraphView extends JPanel implements ActionListener {
 							parent.glassPane.stop();
 							new DialogConfIntEstVar(parent, nl, rejected, alpha);
 						} catch (Exception ex) {
-							if (ex instanceof WrongInputException) {
-								parent.glassPane.stop();
+							parent.glassPane.stop();
+							if (ex instanceof WrongInputException) {								
+								JOptionPane.showMessageDialog(parent, "Invalid values in input fields!", "Invalid values in input fields!", JOptionPane.ERROR_MESSAGE);
 								return null;
 							}
 							ErrorHandler.getInstance().makeErrDialog(ex.getMessage(), ex);
@@ -263,8 +264,9 @@ public class GraphView extends JPanel implements ActionListener {
 					protected Void doInBackground() throws Exception {
 						try {
 							if (!isResultUpToDate()) {
+								rCode = RControl.setSeed();
 								RControl.getR().evalVoid(result+" <- gMCP("+getNL().initialGraph+getGMCPOptions()+")");
-								rCode = RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
+								rCode += RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
 								setResultUpToDate(true);
 							}
 							boolean[] rejected = RControl.getR().eval(result+"@rejected").asRLogical().getData();
@@ -275,8 +277,9 @@ public class GraphView extends JPanel implements ActionListener {
 							parent.glassPane.stop();
 							new RejectedDialog(parent, rejected, parent.getGraphView().getNL().getNodes(), output, rCode);
 						} catch (Exception ex) {
-							if (ex instanceof WrongInputException) {
-								parent.glassPane.stop();
+							parent.glassPane.stop();
+							if (ex instanceof WrongInputException) {								
+								JOptionPane.showMessageDialog(parent, "Invalid values in input fields!", "Invalid values in input fields!", JOptionPane.ERROR_MESSAGE);
 								return null;
 							}
 							ErrorHandler.getInstance().makeErrDialog(ex.getMessage(), ex);
@@ -309,20 +312,22 @@ public class GraphView extends JPanel implements ActionListener {
 					protected Void doInBackground() throws Exception {
 						try {							
 							if (!isResultUpToDate()) {
+								rCode = RControl.setSeed();
 								RControl.getR().evalVoid(result+" <- gMCP("+getNL().initialGraph+getGMCPOptions()+")");
-								rCode = RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
+								rCode += RControl.getR().eval("gMCP:::createGMCPCall("+getNL().initialGraph+getGMCPOptions()+")").asRChar().getData()[0];
 								setResultUpToDate(true);
 							}
 							double[] adjPValues = RControl.getR().eval(result+"@adjPValues").asRNumeric().getData();
 							parent.glassPane.stop();
 							new AdjustedPValueDialog(parent, getPView().pValues, adjPValues, getNL().getNodes());
 						} catch (Exception ex) {
-							if (ex instanceof WrongInputException) {
-								parent.glassPane.stop();
+							parent.glassPane.stop();
+							if (ex instanceof WrongInputException) {								
+								JOptionPane.showMessageDialog(parent, "Invalid values in input fields!", "Invalid values in input fields!", JOptionPane.ERROR_MESSAGE);
 								return null;
 							}
 							ErrorHandler.getInstance().makeErrDialog(ex.getMessage(), ex);
-						} 
+						}
 						return null;
 					}  
 				};
@@ -336,7 +341,7 @@ public class GraphView extends JPanel implements ActionListener {
 	 * to run to anonymous subclasses of SwingWorker.
 	 * See method actionPerformed(ActionEvent e) where it is used.
 	 */
-	String rCode = "";
+	public String rCode = "";
 	public boolean isGraphSaved = true;
 
 	private void showParamInfo() {
@@ -362,7 +367,7 @@ public class GraphView extends JPanel implements ActionListener {
 		if (!getNL().testingStarted) return;
 		getNL().stopTesting();
 		getNL().reset();
-		getNL().loadGraph(getNL().resetGraph);
+		getNL().loadGraph(getNL().resetGraph, false);
 		getDataFramePanel().setTesting(false);
 		getPView().restorePValues();
 		getPView().setTesting(false);
@@ -507,14 +512,17 @@ public class GraphView extends JPanel implements ActionListener {
 
 	public void copyGraphToClipboard() {
 		if (OSTools.isLinux() && !Configuration.getInstance().getClassProperty(this.getClass(), "showClipboardInfo", "yes").equals("no")) {
-			String message = "An old bug from 2007 that is widely known but never\n" +
-					"fixed from Sun/Oracle in Java will most likely prevent this\n" +
-					"feature to work on a Linux machine.\n" +
-					"We are sorry…";
-			JCheckBox tellMeAgain = new JCheckBox("Don't show me this info again.");			
-			JOptionPane.showMessageDialog(parent, new Object[] {message, tellMeAgain}, "Will most likely not work under Linux", JOptionPane.WARNING_MESSAGE);
-			if (tellMeAgain.isSelected()) {
-				Configuration.getInstance().setClassProperty(this.getClass(), "showClipboardInfo", "no");
+			String jsv = System.getProperty("java.specification.version");
+			if (jsv.equals("1.5") || jsv.equals("1.6")) {
+				String message = "An old bug from 2007 that is widely known but never\n" +
+						"fixed by Sun/Oracle in Java will most likely prevent this\n" +
+						"feature to work on a Linux machine.\n" +
+						"We are sorry…";
+				JCheckBox tellMeAgain = new JCheckBox("Don't show me this info again.");			
+				JOptionPane.showMessageDialog(parent, new Object[] {message, tellMeAgain}, "Will most likely not work under Linux", JOptionPane.WARNING_MESSAGE);
+				if (tellMeAgain.isSelected()) {
+					Configuration.getInstance().setClassProperty(this.getClass(), "showClipboardInfo", "no");
+				}
 			}
 		}
 		if (getNL().getNodes().size()==0) {
@@ -551,15 +559,15 @@ public class GraphView extends JPanel implements ActionListener {
 
 	public void addEntangledLayer() {
 		getDataFramePanel().addLayer();
-		getPView().addEntangledLayer();
 		nl.addEntangledLayer();
+		getPView().addEntangledLayer();		
 	}
 	
 	/* This method should be called only from DataFramePanel.removeLayer()
 	 * or if not, DataFramePanel.removeLayer() must be called separately.
 	 */
 	public void removeEntangledLayer(int layer) {
-		nl.removeLayer(layer);
+		nl.removeEntangledLayer(layer);
 		getPView().removeEntangledLayer(layer);
 	}
 }
